# Generated by Django 2.1.11 on 2019-09-17 11:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('aa_stripe', '0021_auto_20190906_1623'),
    ]

    operations = [
        migrations.AddField(
            model_name='stripecharge',
            name='amount_refunded',
            field=models.IntegerField(default=0, help_text='in cents', null=True),
        ),
    ]
